@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.2.8'; # VERSION
+our $VERSION = 'v0.3.0'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -76,7 +76,7 @@ Business::CyberSource::Request::AuthReversal - CyberSource Reverse Authorization
 
 =head1 VERSION
 
-version v0.2.8
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ Additional documentation: provided by the library
 
 Reader: total
 
-Type: Num
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
 Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
 
@@ -192,13 +192,13 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
-=head2 foreign_currency
+=head2 reference_code
 
-Reader: foreign_currency
+Reader: reference_code
 
-Type: MooseX::Types::Locale::Currency::CurrencyCode
+Type: MooseX::Types::Varchar::Varchar[50]
 
-Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
+This attribute is required.
 
 =head2 client_name
 
@@ -208,13 +208,13 @@ Type: Str
 
 Additional documentation: provided by the library
 
-=head2 reference_code
+=head2 foreign_currency
 
-Reader: reference_code
+Reader: foreign_currency
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::Locale::Currency::CurrencyCode
 
-This attribute is required.
+Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
 =head2 client_version
 
@@ -222,6 +222,12 @@ Reader: client_version
 
 Type: Str
 
+=head2 items
+
+Reader: items
+
+Type: ArrayRef[MooseX::Types::CyberSource::Item]
+
 =head1 METHODS
 
 =head2 new
