@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.2.8'; # VERSION
+our $VERSION = 'v0.3.0'; # VERSION
 
 use Moose;
 with qw(
@@ -29,6 +29,10 @@ sub submit {
 		},
 	};
 
+	if ( $self->has_items and not $self->items_is_empty ) {
+		$payload->{item} = [ @{ $self->_item_info } ];
+	}
+
 	my $r = $self->_build_request( $payload );
 
 	my $res;
@@ -82,7 +86,7 @@ sub submit {
 				auth_record    => $r->{ccAuthReply}->{authRecord},
 				processor_response =>
 					$r->{ccAuthReply}->{processorResponse},
-				%{$e},
+			%{$e},
 			})
 			;
 	}
@@ -108,7 +112,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.2.8
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -136,9 +140,47 @@ version v0.2.8
 
 	my $response = $req->submit;
 
+	# or if you want to use items instead of just giving a total
+
+	my $oreq = Business::CyberSource::Request::Authorization->new({
+		username       => 'merchantID',
+		password       => 'transaction key',
+		production     => 0,
+		reference_code => '42',
+		first_name     => 'Caleb',
+		last_name      => 'Cushing',
+		street         => '100 somewhere st',
+		city           => 'Houston',
+		state          => 'TX',
+		zip            => '77064',
+		country        => 'US',
+		email          => 'xenoterracide@gmail.com',
+		currency       => 'USD',
+		items          => [
+			{
+				unit_price => 1000.00,
+				quantity   => 2,
+			},
+			{
+				unit_price => 1000.00,
+				quantity   => 1,
+			},
+		],
+		credit_card    => '4111111111111111',
+		cc_exp_month   => '09',
+		cc_exp_year    => '2025',
+	});
+
+	my $oresponse = $oreq->submit;
+
 =head1 DESCRIPTION
 
-This allows you to create an authorization request.
+Offline authorization means that when you submit an order using a credit card,
+you will not know if the funds are available until you capture the order and
+receive confirmation of payment. You typically will not ship the goods until
+you receive this payment confirmation. For offline credit cards, it will take
+typically five days longer to receive payment confirmation than for online
+cards.
 
 =head1 ATTRIBUTES
 
@@ -152,14 +194,6 @@ This attribute is required.
 
 Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
 
-=head2 ip
-
-Reader: ip
-
-Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
-
-Additional documentation: Customer's IP address. alias: C<ip_address>
-
 =head2 client_env
 
 Reader: client_env
@@ -176,6 +210,144 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 state
+
+Reader: state
+
+Type: MooseX::Types::Varchar::Varchar[2]
+
+Additional documentation: State or province of the billing address. Use the two-character codes. alias: C<province>
+
+=head2 trace
+
+Reader: trace
+
+Writer: trace
+
+Type: XML::Compile::SOAP::Trace
+
+=head2 email
+
+Reader: email
+
+Type: MooseX::Types::Email::EmailAddress
+
+This attribute is required.
+
+Additional documentation: Customer's email address, including the full domain name
+
+=head2 password
+
+Reader: password
+
+Type: MooseX::Types::Common::String::NonEmptyStr
+
+This attribute is required.
+
+Additional documentation: your SOAP transaction key
+
+=head2 cybs_api_version
+
+Reader: cybs_api_version
+
+Type: Str
+
+Additional documentation: provided by the library
+
+=head2 cvn
+
+Reader: cvn
+
+Type: MooseX::Types::CreditCard::CardSecurityCode
+
+Additional documentation: Card Verification Numbers
+
+=head2 total
+
+Reader: total
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
+Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
+
+=head2 cc_exp_month
+
+Reader: cc_exp_month
+
+Type: MooseX::Types::Varchar::Varchar[2]
+
+This attribute is required.
+
+Additional documentation: Two-digit month that the credit card expires in. Format: MM.
+
+=head2 username
+
+Reader: username
+
+Type: MooseX::Types::Varchar::Varchar[30]
+
+This attribute is required.
+
+Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
+
+=head2 card_type
+
+Reader: card_type
+
+Type: MooseX::Types::CyberSource::CardTypeCode
+
+Additional documentation: Type of card to authorize
+
+=head2 credit_card
+
+Reader: credit_card
+
+Type: MooseX::Types::CreditCard::CreditCard
+
+This attribute is required.
+
+Additional documentation: Customer's credit card number
+
+=head2 zip
+
+Reader: zip
+
+Type: MooseX::Types::Varchar::Varchar[10]
+
+Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. alias: C<postal_code>
+
+=head2 street2
+
+Reader: street2
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+Additional documentation: Second line of the billing street address.
+
+=head2 reference_code
+
+Reader: reference_code
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+This attribute is required.
+
+=head2 street3
+
+Reader: street3
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+Additional documentation: Third line of the billing street address.
+
+=head2 ip
+
+Reader: ip
+
+Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
+
+Additional documentation: Customer's IP address. alias: C<ip_address>
+
 =head2 cv_indicator
 
 Reader: cv_indicator
@@ -194,24 +366,6 @@ This attribute is required.
 
 Additional documentation: Customer's last name. The value should be the same as the one that is on the card.
 
-=head2 state
-
-Reader: state
-
-Type: MooseX::Types::Varchar::Varchar[2]
-
-Additional documentation: State or province of the billing address. Use the two-character codes. alias: C<province>
-
-=head2 email
-
-Reader: email
-
-Type: MooseX::Types::Email::EmailAddress
-
-This attribute is required.
-
-Additional documentation: Customer's email address, including the full domain name
-
 =head2 currency
 
 Reader: currency
@@ -220,14 +374,6 @@ Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 This attribute is required.
 
-=head2 trace
-
-Reader: trace
-
-Writer: trace
-
-Type: XML::Compile::SOAP::Trace
-
 =head2 city
 
 Reader: city
@@ -238,16 +384,6 @@ This attribute is required.
 
 Additional documentation: City of the billing address.
 
-=head2 password
-
-Reader: password
-
-Type: MooseX::Types::Common::String::NonEmptyStr
-
-This attribute is required.
-
-Additional documentation: your SOAP transaction key
-
 =head2 production
 
 Reader: production
@@ -258,6 +394,14 @@ This attribute is required.
 
 Additional documentation: 0: test server. 1: production server
 
+=head2 street4
+
+Reader: street4
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+Additional documentation: Fourth line of the billing street address.
+
 =head2 country
 
 Reader: country
@@ -268,40 +412,6 @@ This attribute is required.
 
 Additional documentation: ISO 2 character country code (as it would apply to a credit card billing statement)
 
-=head2 cybs_api_version
-
-Reader: cybs_api_version
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 cvn
-
-Reader: cvn
-
-Type: MooseX::Types::CreditCard::CardSecurityCode
-
-Additional documentation: Card Verification Numbers
-
-=head2 cc_exp_month
-
-Reader: cc_exp_month
-
-Type: MooseX::Types::Varchar::Varchar[2]
-
-This attribute is required.
-
-Additional documentation: Two-digit month that the credit card expires in. Format: MM.
-
-=head2 total
-
-Reader: total
-
-Type: Num
-
-Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
-
 =head2 cc_exp_year
 
 Reader: cc_exp_year
@@ -312,42 +422,6 @@ This attribute is required.
 
 Additional documentation: Four-digit year that the credit card expires in. Format: YYYY.
 
-=head2 username
-
-Reader: username
-
-Type: MooseX::Types::Varchar::Varchar[30]
-
-This attribute is required.
-
-Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
-
-=head2 credit_card
-
-Reader: credit_card
-
-Type: MooseX::Types::CreditCard::CreditCard
-
-This attribute is required.
-
-Additional documentation: Customer's credit card number
-
-=head2 card_type
-
-Reader: card_type
-
-Type: MooseX::Types::CyberSource::CardTypeCode
-
-Additional documentation: Type of card to authorize
-
-=head2 zip
-
-Reader: zip
-
-Type: MooseX::Types::Varchar::Varchar[10]
-
-Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. alias: C<postal_code>
-
 =head2 cybs_xsd
 
 Reader: cybs_xsd
@@ -356,14 +430,6 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
-=head2 street2
-
-Reader: street2
-
-Type: MooseX::Types::Varchar::Varchar[60]
-
-Additional documentation: Second line of the billing street address.
-
 =head2 foreign_currency
 
 Reader: foreign_currency
@@ -372,14 +438,6 @@ Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
-=head2 reference_code
-
-Reader: reference_code
-
-Type: MooseX::Types::Varchar::Varchar[50]
-
-This attribute is required.
-
 =head2 client_name
 
 Reader: client_name
@@ -394,6 +452,12 @@ Reader: client_version
 
 Type: Str
 
+=head2 items
+
+Reader: items
+
+Type: ArrayRef[MooseX::Types::CyberSource::Item]
+
 =head2 first_name
 
 Reader: first_name
