@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.2.8'; # VERSION
+our $VERSION = 'v0.3.0'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -75,7 +75,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version v0.2.8
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -111,14 +111,6 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
-=head2 currency
-
-Reader: currency
-
-Type: MooseX::Types::Locale::Currency::CurrencyCode
-
-This attribute is required.
-
 =head2 trace
 
 Reader: trace
@@ -137,6 +129,48 @@ This attribute is required.
 
 Additional documentation: your SOAP transaction key
 
+=head2 cybs_api_version
+
+Reader: cybs_api_version
+
+Type: Str
+
+Additional documentation: provided by the library
+
+=head2 total
+
+Reader: total
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
+Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
+
+=head2 username
+
+Reader: username
+
+Type: MooseX::Types::Varchar::Varchar[30]
+
+This attribute is required.
+
+Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
+
+=head2 reference_code
+
+Reader: reference_code
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+This attribute is required.
+
+=head2 currency
+
+Reader: currency
+
+Type: MooseX::Types::Locale::Currency::CurrencyCode
+
+This attribute is required.
+
 =head2 production
 
 Reader: production
@@ -155,32 +189,6 @@ Type: MooseX::Types::Varchar::Varchar[29]
 
 This attribute is required.
 
-=head2 cybs_api_version
-
-Reader: cybs_api_version
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 total
-
-Reader: total
-
-Type: Num
-
-Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
-
-=head2 username
-
-Reader: username
-
-Type: MooseX::Types::Varchar::Varchar[30]
-
-This attribute is required.
-
-Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
-
 =head2 cybs_xsd
 
 Reader: cybs_xsd
@@ -189,14 +197,6 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
-=head2 client_name
-
-Reader: client_name
-
-Type: Str
-
-Additional documentation: provided by the library
-
 =head2 foreign_currency
 
 Reader: foreign_currency
@@ -205,13 +205,13 @@ Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
-=head2 reference_code
+=head2 client_name
 
-Reader: reference_code
+Reader: client_name
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: Str
 
-This attribute is required.
+Additional documentation: provided by the library
 
 =head2 client_version
 
@@ -219,6 +219,12 @@ Reader: client_version
 
 Type: Str
 
+=head2 items
+
+Reader: items
+
+Type: ArrayRef[MooseX::Types::CyberSource::Item]
+
 =head1 METHODS
 
 =head2 new
