@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.8'; # VERSION
+our $VERSION = 'v0.3.0'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -28,7 +28,7 @@ Business::CyberSource::Request::StandAloneCredit - CyberSource Credit Request Ob
 
 =head1 VERSION
 
-version v0.2.8
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -72,14 +72,6 @@ This attribute is required.
 
 Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
 
-=head2 ip
-
-Reader: ip
-
-Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
-
-Additional documentation: Customer's IP address. alias: C<ip_address>
-
 =head2 client_env
 
 Reader: client_env
@@ -96,24 +88,6 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
-=head2 cv_indicator
-
-Reader: cv_indicator
-
-Type: MooseX::Types::CyberSource::CvIndicator
-
-Additional documentation: Flag that indicates whether a CVN code was sent
-
-=head2 last_name
-
-Reader: last_name
-
-Type: MooseX::Types::Varchar::Varchar[60]
-
-This attribute is required.
-
-Additional documentation: Customer's last name. The value should be the same as the one that is on the card.
-
 =head2 state
 
 Reader: state
@@ -140,24 +114,6 @@ Writer: trace
 
 Type: XML::Compile::SOAP::Trace
 
-=head2 currency
-
-Reader: currency
-
-Type: MooseX::Types::Locale::Currency::CurrencyCode
-
-This attribute is required.
-
-=head2 city
-
-Reader: city
-
-Type: MooseX::Types::Varchar::Varchar[50]
-
-This attribute is required.
-
-Additional documentation: City of the billing address.
-
 =head2 password
 
 Reader: password
@@ -168,26 +124,6 @@ This attribute is required.
 
 Additional documentation: your SOAP transaction key
 
-=head2 production
-
-Reader: production
-
-Type: Bool
-
-This attribute is required.
-
-Additional documentation: 0: test server. 1: production server
-
-=head2 country
-
-Reader: country
-
-Type: MooseX::Types::Locale::Country::Alpha2Country
-
-This attribute is required.
-
-Additional documentation: ISO 2 character country code (as it would apply to a credit card billing statement)
-
 =head2 cybs_api_version
 
 Reader: cybs_api_version
@@ -218,20 +154,10 @@ Additional documentation: Two-digit month that the credit card expires in. Forma
 
 Reader: total
 
-Type: Num
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
 Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
 
-=head2 cc_exp_year
-
-Reader: cc_exp_year
-
-Type: MooseX::Types::Varchar::Varchar[4]
-
-This attribute is required.
-
-Additional documentation: Four-digit year that the credit card expires in. Format: YYYY.
-
 =head2 username
 
 Reader: username
@@ -268,14 +194,6 @@ Type: MooseX::Types::Varchar::Varchar[10]
 
 Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. alias: C<postal_code>
 
-=head2 cybs_xsd
-
-Reader: cybs_xsd
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 street2
 
 Reader: street2
@@ -284,13 +202,111 @@ Type: MooseX::Types::Varchar::Varchar[60]
 
 Additional documentation: Second line of the billing street address.
 
-=head2 foreign_currency
+=head2 reference_code
 
-Reader: foreign_currency
+Reader: reference_code
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+This attribute is required.
+
+=head2 street3
+
+Reader: street3
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+Additional documentation: Third line of the billing street address.
+
+=head2 ip
+
+Reader: ip
+
+Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
+
+Additional documentation: Customer's IP address. alias: C<ip_address>
+
+=head2 cv_indicator
+
+Reader: cv_indicator
+
+Type: MooseX::Types::CyberSource::CvIndicator
+
+Additional documentation: Flag that indicates whether a CVN code was sent
+
+=head2 last_name
+
+Reader: last_name
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+This attribute is required.
+
+Additional documentation: Customer's last name. The value should be the same as the one that is on the card.
+
+=head2 currency
+
+Reader: currency
 
 Type: MooseX::Types::Locale::Currency::CurrencyCode
 
-Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
+This attribute is required.
+
+=head2 city
+
+Reader: city
+
+Type: MooseX::Types::Varchar::Varchar[50]
+
+This attribute is required.
+
+Additional documentation: City of the billing address.
+
+=head2 production
+
+Reader: production
+
+Type: Bool
+
+This attribute is required.
+
+Additional documentation: 0: test server. 1: production server
+
+=head2 street4
+
+Reader: street4
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+Additional documentation: Fourth line of the billing street address.
+
+=head2 country
+
+Reader: country
+
+Type: MooseX::Types::Locale::Country::Alpha2Country
+
+This attribute is required.
+
+Additional documentation: ISO 2 character country code (as it would apply to a credit card billing statement)
+
+=head2 cc_exp_year
+
+Reader: cc_exp_year
+
+Type: MooseX::Types::Varchar::Varchar[4]
+
+This attribute is required.
+
+Additional documentation: Four-digit year that the credit card expires in. Format: YYYY.
+
+=head2 cybs_xsd
+
+Reader: cybs_xsd
+
+Type: MooseX::Types::Path::Class::File
+
+Additional documentation: provided by the library
 
 =head2 client_name
 
@@ -300,13 +316,13 @@ Type: Str
 
 Additional documentation: provided by the library
 
-=head2 reference_code
+=head2 foreign_currency
 
-Reader: reference_code
+Reader: foreign_currency
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::Locale::Currency::CurrencyCode
 
-This attribute is required.
+Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
 =head2 client_version
 
@@ -324,6 +340,12 @@ This attribute is required.
 
 Additional documentation: Customer's first name.The value should be the same as the one that is on the card.
 
+=head2 items
+
+Reader: items
+
+Type: ArrayRef[MooseX::Types::CyberSource::Item]
+
 =head1 METHODS
 
 =head2 new
