@@ -4,9 +4,19 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.8'; # VERSION
+our $VERSION = 'v0.3.0'; # VERSION
 
-use MooseX::Types -declare => [ qw( Decision CardTypeCode CvIndicator ) ];
+use MooseX::Types -declare => [ qw(
+	Decision
+	CardTypeCode
+	CvIndicator
+	CvResults
+	Item
+) ];
+
+use MooseX::Types::Common::Numeric qw( PositiveOrZeroNum );
+use MooseX::Types::Moose qw( Int Num Str );
+use MooseX::Types::Structured qw( Dict Optional );
 
 enum Decision, [ qw( ACCEPT REJECT ERROR REVIEW ) ];
 
@@ -36,6 +46,14 @@ enum CardTypeCode, [ qw(
 
 enum CvIndicator, [ qw( 0 1 2 9 ) ];
 
+subtype Item,
+	as Dict[
+		unit_price => PositiveOrZeroNum,
+		quantity   => Int,
+	];
+
+enum CvResults, [ qw( D I M N P S U X 1 2 3 ) ];
+
 1;
 
 # ABSTRACT: Moose Types specific to CyberSource
@@ -50,7 +68,7 @@ MooseX::Types::CyberSource - Moose Types specific to CyberSource
 
 =head1 VERSION
 
-version v0.2.8
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -136,6 +154,15 @@ L<Business::CyberSource::Request::Role::CreditCardInfo>
 
 =back
 
+=item * C<CvResults>
+
+Base Type: C<enum>
+
+Single character code that defines the result of having sent a CVN. See
+L<CyberSource's Documentation on Card Verification Results
+|http://www.cybersource.com/support_center/support_documentation/quick_references/view.php?page_id=421>
+for more information.
+
 =back
 
 =head1 BUGS
